﻿using System;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using Dienstfahrten.Klassen;
using Microsoft.SharePoint;
using Dienstfahrten.Logging;
using System.Collections.Generic;
using System.Web.UI.HtmlControls;
using Dienstfahrten.Dienstfahrten;

namespace Dienstfahrten.ControlTemplates.Dienstfahrten
{
    public partial class menuUserControl : UserControl
    {
        SPWeb currentWeb;
        Log log;
        List<HtmlGenericControl> menuDivs;
        List<HtmlGenericControl> seitenDivs;

        public ControlCollection menuControl { get; set; }
        public KonfigurationUserControl konfControl { get; set; }
        public DienstfahrtenUserControl dfControl { get; set; }
        public DienstfahrtenListeUserControl dlControl { get; set; }

        protected void Page_Load(object sender, EventArgs e)
        {
            currentWeb = SPContext.Current.Web;
            log = new Log();
            //loadData();

            if (!Page.IsPostBack)
            {
                
            }

        }       

        /// <summary>
        /// Initialisiere Sichtbarkeint der Info/Fehler-Ausgaben
        /// </summary>
        private void init()
        {
            menuDivs = new List<HtmlGenericControl>();
            menuDivs.Add(dfDiv);
            menuDivs.Add(dlDiv);
            menuDivs.Add(konfDiv);
            
            seitenDivs = new List<HtmlGenericControl>();            
            seitenDivs.Add(dfControl.DienstfahrtenSeiteDiv);
            seitenDivs.Add(dlControl.DienstfahrtenListeSeiteDiv);
            seitenDivs.Add(konfControl.KonfigurationSeiteDiv);
        }

        /// <summary>
        /// Falls noch keine User-Daten vorhanden sind, lade die Konfiguration, sonst die Dienstfahrt Ansicht
        /// </summary>
        public void loadData(SPWeb currentWeb)
        {
            init();

            //Konfiguration
            Konfiguration konf = new Konfiguration(currentWeb);
            konf = (Konfiguration)konf.getByUser(currentWeb.CurrentUser);
            if (konf == null)
            {
                //Zuerst müssen die persönlichen Daten gepflegt werden
                setSeite(helper.Seite.konfiguration);
                setMenuAktiv(konfDiv, menuDivs);
                return;
            }
            else
            {
                setSeite(helper.Seite.dienstfahrt);
                setMenuAktiv(dfDiv, menuDivs);
            }
        }
        /// <summary>
        /// Macht die übergebene Seite sichtbar und läd Initialdaten
        /// </summary>
        /// <param name="seite"></param>
        public void setSeite(helper.Seite seite)
        {
            SPWeb currentWeb = SPContext.Current.Web;
            foreach (HtmlGenericControl item in seitenDivs)
            {
                item.Visible = false;
            }

            switch (seite)
            {
                case helper.Seite.dienstfahrt:
                    dfControl.DienstfahrtenSeiteDiv.Visible = true;
                    //dfControl.loadData(currentWeb);
                    break;
                case helper.Seite.dienstfahrtListe:
                    dlControl.DienstfahrtenListeSeiteDiv.Visible = true;
                    //dlControl.loadData(currentWeb);
                    break;
                case helper.Seite.konfiguration:
                    konfControl.KonfigurationSeiteDiv.Visible = true;
                    konfControl.loadData(currentWeb);
                    break;
                default:
                    konfControl.KonfigurationSeiteDiv.Visible = true;
                    konfControl.loadData(currentWeb);
                    break;
            }

        }

        /// <summary>
        /// Setzt das jeweilige Menü als aktiv (fügt CSS Klasse hinzu)
        /// </summary>
        /// <param name="aktiv"></param>
        /// <param name="liste"></param>
        public static void setMenuAktiv(HtmlGenericControl aktiv, List<HtmlGenericControl> liste)
        {
            foreach (HtmlGenericControl item in liste)
            {
                item.Attributes["class"] = "ms-standardheader ms-WPTitle menubutton";
            }
            aktiv.Attributes["class"] += " aktiv";
        }

        /// <summary>
        /// Setzt die jeweilige Seite sichtbar -- abgelöst durch neue setSeite
        /// </summary>
        /// <param name="aktiv"></param>
        /// <param name="liste"></param>
        /*
        private void _setSeite(HtmlGenericControl aktiv, List<HtmlGenericControl> liste)
        {
            foreach (HtmlGenericControl item in liste)
            {
                item.Visible = false;
            }
            aktiv.Visible = true;
        }*/


        /// <summary>
        /// Menü-Button Aktion
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void menuButton_click(object sender, CommandEventArgs e)
        {
            if (e.CommandName == "menuCommand" && e.CommandArgument.ToString() != string.Empty)
            {
                //Konfiguration
                Konfiguration konf = new Konfiguration(currentWeb);
                Konfiguration test = (Konfiguration)konf.getByUser(currentWeb.CurrentUser);
               
                if (test == null)
                {
                    //Zuerst müssen die persönlichen Daten gepflegt werden
                    setSeite(helper.Seite.konfiguration);
                    setMenuAktiv(konfDiv, menuDivs);
                    return;
                }


                string seite = e.CommandArgument.ToString();

                switch (seite)
                {
                    case "dienstfahrt":
                        setMenuAktiv(dfDiv, menuDivs);
                        setSeite(helper.Seite.dienstfahrt);
                        break;
                    case "liste":
                        setMenuAktiv(dlDiv, menuDivs);
                        setSeite(helper.Seite.dienstfahrtListe);
                        dlControl.loadData(currentWeb);
                        break;
                    case "konf":
                        setMenuAktiv(konfDiv, menuDivs);
                        setSeite(helper.Seite.konfiguration);
                        break;
                    default:
                        setMenuAktiv(konfDiv, menuDivs);
                        break;
                }

            }
        }


    }
}
